"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WS_EVENT_CODE_ENUM = exports.isWsPong = exports.getMaxTopicsPerSubscribeEvent = exports.getWsUrlForWsKey = exports.getWsKeyForMarket = exports.getWsKeyForTopicChannel = exports.PUBLIC_WS_KEYS = exports.PRIVATE_WS_KEYS = exports.WS_KEY_MAP = exports.WS_BASE_URL_MAP = void 0;
const typeGuards_1 = require("./typeGuards");
exports.WS_BASE_URL_MAP = {
    prod: {
        public: 'wss://ws.okx.com:8443/ws/v5/public',
        private: 'wss://ws.okx.com:8443/ws/v5/private',
    },
    aws: {
        public: 'wss://wsaws.okx.com:8443/ws/v5/public',
        private: 'wss://wsaws.okx.com:8443/ws/v5/private',
    },
    demo: {
        public: 'wss://wspap.okx.com:8443/ws/v5/public?brokerId=9999',
        private: 'wss://wspap.okx.com:8443/ws/v5/private?brokerId=9999',
    },
};
exports.WS_KEY_MAP = {
    prodPublic: 'prodPublic',
    prodPrivate: 'prodPrivate',
    awsPublic: 'awsPublic',
    awsPrivate: 'awsPrivate',
    demoPublic: 'demoPublic',
    demoPrivate: 'demoPrivate',
};
exports.PRIVATE_WS_KEYS = [
    exports.WS_KEY_MAP.prodPrivate,
    exports.WS_KEY_MAP.awsPrivate,
    exports.WS_KEY_MAP.demoPrivate,
];
exports.PUBLIC_WS_KEYS = [
    exports.WS_KEY_MAP.prodPublic,
    exports.WS_KEY_MAP.awsPublic,
    exports.WS_KEY_MAP.demoPublic,
];
/** Used to automatically determine if a sub request should be to the public or private ws (when there's two) */
const PRIVATE_CHANNELS = [
    'account',
    'positions',
    'balance_and_position',
    'orders',
    'orders-algo',
    'algo-advance',
    'liquidation-warning',
    'account-greeks',
    'grid-orders-spot',
    'grid-orders-contract',
    'grid-orders-moon',
    'grid-positions',
    'grid-sub-orders',
];
/** Determine which WsKey (ws connection) to route an event to */
function getWsKeyForTopicChannel(market, channel, isPrivate) {
    const isPrivateTopic = isPrivate === true || PRIVATE_CHANNELS.includes(channel);
    return getWsKeyForMarket(market, isPrivateTopic);
}
exports.getWsKeyForTopicChannel = getWsKeyForTopicChannel;
function getWsKeyForMarket(market, isPrivate) {
    switch (market) {
        case 'prod': {
            return isPrivate ? exports.WS_KEY_MAP.prodPrivate : exports.WS_KEY_MAP.prodPublic;
        }
        case 'aws': {
            return isPrivate ? exports.WS_KEY_MAP.awsPrivate : exports.WS_KEY_MAP.awsPublic;
        }
        case 'demo': {
            return isPrivate ? exports.WS_KEY_MAP.demoPrivate : exports.WS_KEY_MAP.demoPublic;
        }
        default: {
            throw (0, typeGuards_1.neverGuard)(market, `getWsKeyForTopic(): Unhandled market`);
        }
    }
}
exports.getWsKeyForMarket = getWsKeyForMarket;
/** Maps a WS key back to a WS URL */
function getWsUrlForWsKey(wsKey, wsClientOptions) {
    if (wsClientOptions.wsUrl) {
        return wsClientOptions.wsUrl;
    }
    switch (wsKey) {
        case 'prodPublic':
            return exports.WS_BASE_URL_MAP.prod.public;
        case 'prodPrivate':
            return exports.WS_BASE_URL_MAP.prod.private;
        case 'awsPublic':
            return exports.WS_BASE_URL_MAP.aws.public;
        case 'awsPrivate':
            return exports.WS_BASE_URL_MAP.aws.private;
        case 'demoPublic':
            return exports.WS_BASE_URL_MAP.demo.public;
        case 'demoPrivate':
            return exports.WS_BASE_URL_MAP.demo.private;
        default: {
            const errorMessage = 'getWsUrl(): Unhandled wsKey: ';
            this.logger.error(errorMessage, {
                category: 'okx-ws',
                wsKey,
            });
            throw (0, typeGuards_1.neverGuard)(wsKey, errorMessage);
        }
    }
}
exports.getWsUrlForWsKey = getWsUrlForWsKey;
function getMaxTopicsPerSubscribeEvent(market) {
    switch (market) {
        case 'prod':
        case 'aws':
        case 'demo': {
            return null;
        }
        default: {
            throw (0, typeGuards_1.neverGuard)(market, `getWsKeyForTopic(): Unhandled market`);
        }
    }
}
exports.getMaxTopicsPerSubscribeEvent = getMaxTopicsPerSubscribeEvent;
function isWsPong(event) {
    return (typeof event === 'object' &&
        !!event &&
        'data' in event &&
        typeof event['data'] === 'string' &&
        event['data'] === 'pong');
}
exports.isWsPong = isWsPong;
exports.WS_EVENT_CODE_ENUM = {
    OK: '0',
    LOGIN_FAILED: '60009',
    LOGIN_PARTIALLY_FAILED: '60022',
};
//# sourceMappingURL=websocket-util.js.map